package com.ebei.screen.common.util;

import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSON;
import com.ebei.screen.common.constants.EbaSystemConstants;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * EBA大屏工具类
 *
 * @author Levi.u
 * @date 2021/1/13 21:03
 */
@Slf4j
@Component
public class EbaUtils {

    private static Integer SUCCESS_CODE = 200;

    private static MongoTemplate mongoTemplate;

    private static Levi PARAMS = Levi.by("clientId", EbaSystemConstants.cliendId).set("clientSecret", EbaSystemConstants.clientSecret);

    @Autowired
    public void setMongoTemplate(MongoTemplate mongoTemplate) {
        EbaUtils.mongoTemplate = mongoTemplate;
    }

    /**
     * 判断执行结果是否成功
     *
     * @param result true成功 false失败
     * @return
     */
    public static boolean isSuccess(String result) {
        return SUCCESS_CODE.equals(JSON.parseObject(result).getInteger("code"));
    }

    /**
     * 获取EBA大屏token
     *
     * @return
     */
    public static String getToken() {
        String result = HttpRequest.post(EbaSystemConstants.tokenGetInfo)
                .header("content-type", "application/json")
                .body(JSON.toJSONString(PARAMS))
                .execute().body();
        log.info("#########> 获取token:{} 参数:{}", result, JSON.toJSONString(PARAMS));
        return LeviUtils.getJsonFieldOne(result, "data.token", String.class);
    }

    /**
     * 当前用户下项目列表
     * @return
     */
    public static List<Map> getProjectList(){
        String result = HttpRequest.post(EbaSystemConstants.projectGetList)
                .header("token", getToken())
                .body(JSON.toJSONString(PARAMS))
                .execute().body();
        log.info("#########> 获取token:{} 参数:{}", result, JSON.toJSONString(PARAMS));
        return LeviUtils.getJsonFieldMany(result, "data.projectList",Map.class);
    }

    /**
     * 项目下所有设备列表
     * @return
     */
    public static List<Map> getDeviceList(){
        String result = HttpRequest.post(EbaSystemConstants.deviceGetDevice)
                .body("{\n\t\"projectId\":1250\n}")
                .header("token", getToken())
                .body(JSON.toJSONString(PARAMS))
                .execute().body();
        log.info("#########> 获取token:{} 参数:{}", result, JSON.toJSONString(PARAMS));
        return LeviUtils.getJsonFieldMany(result, "data.projectList",Map.class);
    }
}
